@@ -194,6 +194,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteRouteTriggerTime(self, request):
+        """This API is used to modify the delayed trigger time of route deletion.
+
+        :param request: Request instance for DeleteRouteTriggerTime.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteTriggerTimeRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteTriggerTimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteRouteTriggerTime", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteRouteTriggerTimeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTopic(self, request):
         """This API is used to delete a CKafka topic.
 
