@@ -782,6 +782,34 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def KillMySqlThreads(self, request):
+        """This API is used to interrupt the current session according to the session ID. It needs to be called twice to commit the session interruption task in two stages. In the pre-commit stage, the stage value is `Prepare`, and the returned value is `SqlExecId’. In the commit stage, the stage value is `Commit`, and `SqlExecId` will be passed in as a parameter. Then the session process will be terminated.
+
+        :param request: Request instance for KillMySqlThreads.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.KillMySqlThreadsRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.KillMySqlThreadsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("KillMySqlThreads", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.KillMySqlThreadsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDiagDBInstanceConf(self, request):
         """This API is used to enable/disable instance inspection.
 
