@@ -243,22 +243,22 @@ class CreateAppRequest(AbstractModel):
         
 
 
-class CreateAppResponse(AbstractModel):
-    """CreateApp output parameters
+class CreateAppResp(AbstractModel):
+    """Output parameters of `CreateApp`
 
     """
 
     def __init__(self):
         r"""
-        :param BizId: Application ID, which is automatically generated by the backend.
+        :param BizId: App ID, automatically generated by the backend.
         :type BizId: int
-        :param AppName: Application name, which is passed through from the `AppName` input parameter
+        :param AppName: App name, the input of `AppName`.
         :type AppName: str
-        :param ProjectId: Project ID, which is passed through from the entered `ProjectId`
+        :param ProjectId: Project ID, the input of `ProjectId`.
         :type ProjectId: int
-        :param SecretKey: Application key, which is used when the GME SDK is initialized
+        :param SecretKey: App key, used to initialize GME SDK.
         :type SecretKey: str
-        :param CreateTime: Service creation timestamp
+        :param CreateTime: Timestamp, indicating when the service is created.
         :type CreateTime: int
         :param RealtimeSpeechConf: Configuration information of voice chat
         :type RealtimeSpeechConf: :class:`tencentcloud.gme.v20180711.models.RealtimeSpeechConf`
@@ -292,6 +292,36 @@ class CreateAppResponse(AbstractModel):
         if params.get("VoiceFilterConf") is not None:
             self.VoiceFilterConf = VoiceFilterConf()
             self.VoiceFilterConf._deserialize(params.get("VoiceFilterConf"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateAppResponse(AbstractModel):
+    """CreateApp response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: Returned data
+        :type Data: :class:`tencentcloud.gme.v20180711.models.CreateAppResp`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = CreateAppResp()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
 
 
 class DescribeAppStatisticsRequest(AbstractModel):
@@ -330,14 +360,14 @@ class DescribeAppStatisticsRequest(AbstractModel):
         
 
 
-class DescribeAppStatisticsResponse(AbstractModel):
-    """Gets application usage statistics output parameters
+class DescribeAppStatisticsResp(AbstractModel):
+    """Output parameters of app usage statistics
 
     """
 
     def __init__(self):
         r"""
-        :param AppStatistics: Application usage statistics
+        :param AppStatistics: App usage statistics
         :type AppStatistics: list of AppStatisticsItem
         """
         self.AppStatistics = None
@@ -350,6 +380,36 @@ class DescribeAppStatisticsResponse(AbstractModel):
                 obj = AppStatisticsItem()
                 obj._deserialize(item)
                 self.AppStatistics.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeAppStatisticsResponse(AbstractModel):
+    """DescribeAppStatistics response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: App usage statistics
+        :type Data: :class:`tencentcloud.gme.v20180711.models.DescribeAppStatisticsResp`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = DescribeAppStatisticsResp()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
 
 
 class DescribeApplicationDataRequest(AbstractModel):
@@ -572,16 +632,16 @@ class ModifyAppStatusRequest(AbstractModel):
         
 
 
-class ModifyAppStatusResponse(AbstractModel):
-    """ModifyAppStatus API output parameters
+class ModifyAppStatusResp(AbstractModel):
+    """Output parameters of `ModifyAppStatus`
 
     """
 
     def __init__(self):
         r"""
-        :param BizId: GME application ID
+        :param BizId: GME app ID
         :type BizId: int
-        :param Status: Application status. Valid values: open, close
+        :param Status: App status. Valid values: `open`, `close`
         :type Status: str
         """
         self.BizId = None
@@ -591,6 +651,36 @@ class ModifyAppStatusResponse(AbstractModel):
     def _deserialize(self, params):
         self.BizId = params.get("BizId")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyAppStatusResponse(AbstractModel):
+    """ModifyAppStatus response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: Returned data
+        :type Data: :class:`tencentcloud.gme.v20180711.models.ModifyAppStatusResp`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = ModifyAppStatusResp()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
 
 
 class RealTimeSpeechStatisticsItem(AbstractModel):
@@ -646,7 +736,7 @@ class RealtimeSpeechConf(AbstractModel):
         r"""
         :param Status: Voice chat status. Valid values: open, close
         :type Status: str
-        :param Quality: Voice chat sound quality type. Valid values: high (HD), ordinary (SD). Default value: high. SD sound quality is only available to allowllisted users. To try it out, please contact your Tencent Cloud rep.
+        :param Quality: Voice chat sound quality. Valid value: `high`
         :type Quality: str
         """
         self.Status = None
